# server_launch.py
import os
from brotli_asgi import BrotliMiddleware
from fastapi import FastAPI, Header, HTTPException
from fastapi.middleware.cors import CORSMiddleware
from fastapi.staticfiles import StaticFiles # static html files deploying
from typing import List,Optional
from pydantic import BaseModel

import dbconnect
import emailfuncs

root = os.path.dirname(__file__)

# app = FastAPI(openapi_url="/api/tracking/openapi.json")
app = FastAPI()

# allow cors - from https://fastapi.tiangolo.com/tutorial/cors/
app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

# enable Brotli compression. Better for json payloads, supported by most browsers. 
# Fallback to gzip by default. from https://github.com/fullonic/brotli-asgi
app.add_middleware(BrotliMiddleware)


@app.get("/api/listrows", tags=["users"])
def listrows(X_Forwarded_For: Optional[str] = Header(None)):
    print(f"listrows GET api call from {X_Forwarded_For}")
    s1 = "select * from test1"
    list1 = dbconnect.makeQuery(s1, output="list")
    returnD = {
        "success": True,
        "list": list1
    }
    return returnD


@app.get("/api/addrow", tags=["users"])
def addrow(value: str, X_Forwarded_For: Optional[str] = Header(None)):
    print(f"addrow GET api call from {X_Forwarded_For}")
    
    i1 = f"insert into test1 (val) VALUES ('{value}')"
    i1Count = dbconnect.execSQL(i1)
    
    if not i1Count:
        raise HTTPException(status_code=400, detail="DB insert error")
    
    returnD = {
        "success": True,
    }
    return returnD


class emailapi_payload(BaseModel):
    content: str
    subject: str
    recipients: List[str]

@app.post("/api/emailapi", tags=["users"])
def emailapi(r:emailapi_payload, X_Forwarded_For: Optional[str] = Header(None)):
    print(f"emailapi GET api call from {X_Forwarded_For}")
    result = emailfuncs.sendEmail(r.content, r.subject, r.recipients)
    returnD = {"success": True, "result": result}
    return returnD


app.mount("/", StaticFiles(directory="html", html = True), name="static")
